# CSBRAIN v0.0.1

This was a package designed for the sole purpose of designing and making Data allocation and data science easier for all coders. This package contains functions which can allocate data from SQL .db files into a .txt file written with a special notation that can be processed by this library and is easy to encrypt. 


Github: [https://github.com/Phytonking/CSBrain]